@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,7 +16,9 @@
 */
 
 #include "configurepluginslistwidget.h"
+#include "helper_p.h"
 #include "kmail_debug.h"
+#include "util.h"
 #include "../../plugininterface/kmailplugininterface.h"
 #include <MessageViewer/ViewerPluginManager>
 #include <MessageViewer/HeaderStylePluginManager>
@@ -113,8 +115,8 @@ void ConfigurePluginsListWidget::save()
 
 void ConfigurePluginsListWidget::saveAkonadiAgent()
 {
-    Q_FOREACH (PluginItem *item, mAgentPluginsItems) {
-        Q_FOREACH (const PimCommon::PluginUtilData &data, mPluginUtilDataList) {
+    for (PluginItem *item : qAsConst(mAgentPluginsItems)) {
+        for (const PimCommon::PluginUtilData &data : qAsConst(mPluginUtilDataList)) {
             if (item->mIdentifier == data.mIdentifier) {
                 changeAgentActiveState(data.mExtraInfo.at(0), data.mExtraInfo.at(1), item->checkState(0) == Qt::Checked);
                 break;
@@ -200,6 +202,7 @@ void ConfigurePluginsListWidget::initialize()
 void ConfigurePluginsListWidget::initializeAgentPlugins()
 {
     mPluginUtilDataList.clear();
+    mPluginUtilDataList.reserve(4);
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_sendlater_agent"), QStringLiteral("/SendLaterAgent"));
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_archivemail_agent"), QStringLiteral("/ArchiveMailAgent"));
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_newmailnotifier_agent"), QStringLiteral("/NewMailNotifierAgent"));
@@ -219,7 +222,8 @@ PimCommon::PluginUtilData ConfigurePluginsListWidget::createAgentPluginData(cons
     PimCommon::PluginUtilData data;
     data.mEnableByDefault = true;
     data.mHasConfigureDialog = true;
-    Q_FOREACH (const Akonadi::AgentType &type, Akonadi::AgentManager::self()->types()) {
+    const Akonadi::AgentType::List lstAgent = Akonadi::AgentManager::self()->types();
+    for (const Akonadi::AgentType &type : lstAgent) {
         if (type.identifier() == interfaceName) {
             data.mExtraInfo << interfaceName;
             data.mExtraInfo << path;
@@ -289,7 +293,7 @@ void ConfigurePluginsListWidget::slotConfigureClicked(const QString &configureGr
             MessageComposer::PluginEditorCheckBeforeSend *plugin = MessageComposer::PluginEditorCheckBeforeSendManager::self()->pluginFromIdentifier(identifier);
             plugin->showConfigureDialog(this);
         } else if (configureGroupName == agentAkonadiGroupName()) {
-            Q_FOREACH (const PimCommon::PluginUtilData &data, mPluginUtilDataList) {
+            for (const PimCommon::PluginUtilData &data : qAsConst(mPluginUtilDataList)) {
                 if (data.mIdentifier == identifier) {
                     QDBusInterface interface(QLatin1String("org.freedesktop.Akonadi.Agent.") + data.mExtraInfo.at(0), data.mExtraInfo.at(1));
                     if (interface.isValid()) {
